Calibrates the Federal Crop Insurance Program (FCIP) yield for a single crop year by finding the optimal production history length (T_0, T_1) and yield offset dy_Opt that minimize the squared deviation between observed rates and the model-predicted rate in the following year. Uses a data.table-based grid search over integer T_0[2,10], T_1[3,10], and an optimize() call for dy_Opt.

calibrate_yield(
  sobtpu_current,
  sobtpu_subsequent,
  control = rfcipPackage_controls()
)

Arguments

sobtpu_current

The target year prepared sobtpu, typically returned by prepare_yield_calibration_data.

sobtpu_subsequent

The prepared sobtpu for the year immediately following the target year, typically returned by prepare_yield_calibration_data.

control

a list of control parameters;continuous_integration_session set via control to determine the ADM source. see rfcipPackage_controls.

Value

A data.table containing, for each insurance-pool-election record with a calibrated yield

References

Tsiboe, Francis, Dylan Turner, and Jisang Yu. (2025) Utilizing large-scale insurance data sets to calibrate sub-county level crop yields. Journal of Risk and Insurance, 92(1), 139-165.