Deletes the entire cache directory used by the rfcipCalibrate package to store downloaded data files. Useful if you need to force re-download of data, or free up disk space.

clear_rfcipCalibrate_cache()

Value

Invisibly returns NULL. A message is printed indicating which directory was cleared.